from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.UserDataTasks
import win32more.Windows.ApplicationModel.UserDataTasks.DataProvider
import win32more.Windows.Foundation
import win32more.Windows.Win32.System.WinRT
class IUserDataTaskDataProviderConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection'
    _iid_ = Guid('{9ff39d1d-a447-428b-afe9-e5402bdeb041}')
    @winrt_commethod(6)
    def add_CreateOrUpdateTaskRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection, win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCreateOrUpdateTaskRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_CreateOrUpdateTaskRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_SyncRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection, win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSyncManagerSyncRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_SyncRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_SkipOccurrenceRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection, win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSkipOccurrenceRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_SkipOccurrenceRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_CompleteTaskRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection, win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCompleteTaskRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_CompleteTaskRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_DeleteTaskRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection, win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListDeleteTaskRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_DeleteTaskRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def Start(self) -> Void: ...
    CreateOrUpdateTaskRequested = event()
    SyncRequested = event()
    SkipOccurrenceRequested = event()
    CompleteTaskRequested = event()
    DeleteTaskRequested = event()
class IUserDataTaskDataProviderTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderTriggerDetails'
    _iid_ = Guid('{ae273202-b1c9-453e-afc5-b30af3bd217d}')
    @winrt_commethod(6)
    def get_Connection(self) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection: ...
    Connection = property(get_Connection, None)
class IUserDataTaskListCompleteTaskRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCompleteTaskRequest'
    _iid_ = Guid('{f65e14a3-1a42-49da-8552-2873e52c55eb}')
    @winrt_commethod(6)
    def get_TaskListId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_TaskId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def ReportCompletedAsync(self, completedTaskId: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    TaskId = property(get_TaskId, None)
    TaskListId = property(get_TaskListId, None)
class IUserDataTaskListCompleteTaskRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCompleteTaskRequestEventArgs'
    _iid_ = Guid('{d77c393d-4cf2-48ad-87fd-963f0eaa7a95}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCompleteTaskRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IUserDataTaskListCreateOrUpdateTaskRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCreateOrUpdateTaskRequest'
    _iid_ = Guid('{2133772c-55c2-4300-8279-04326e07cce4}')
    @winrt_commethod(6)
    def get_TaskListId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Task(self) -> win32more.Windows.ApplicationModel.UserDataTasks.UserDataTask: ...
    @winrt_commethod(8)
    def ReportCompletedAsync(self, createdOrUpdatedUserDataTask: win32more.Windows.ApplicationModel.UserDataTasks.UserDataTask) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    Task = property(get_Task, None)
    TaskListId = property(get_TaskListId, None)
class IUserDataTaskListCreateOrUpdateTaskRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCreateOrUpdateTaskRequestEventArgs'
    _iid_ = Guid('{12c55a52-e378-419b-ae38-a5e9e604476e}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCreateOrUpdateTaskRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IUserDataTaskListDeleteTaskRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListDeleteTaskRequest'
    _iid_ = Guid('{4b863c68-7657-4f3d-b074-d47ec8df07e7}')
    @winrt_commethod(6)
    def get_TaskListId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_TaskId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    TaskId = property(get_TaskId, None)
    TaskListId = property(get_TaskListId, None)
class IUserDataTaskListDeleteTaskRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListDeleteTaskRequestEventArgs'
    _iid_ = Guid('{6063dad9-f562-4145-8efe-d50078c92b7f}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListDeleteTaskRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IUserDataTaskListSkipOccurrenceRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSkipOccurrenceRequest'
    _iid_ = Guid('{ab87e34d-1cd3-431c-9f58-089aa4338d85}')
    @winrt_commethod(6)
    def get_TaskListId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_TaskId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    TaskId = property(get_TaskId, None)
    TaskListId = property(get_TaskListId, None)
class IUserDataTaskListSkipOccurrenceRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSkipOccurrenceRequestEventArgs'
    _iid_ = Guid('{7a3b924a-cc2f-4e7b-aacd-a5b9d29cfa4e}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSkipOccurrenceRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IUserDataTaskListSyncManagerSyncRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSyncManagerSyncRequest'
    _iid_ = Guid('{40a73807-7590-4149-ae19-b211431a9f48}')
    @winrt_commethod(6)
    def get_TaskListId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    TaskListId = property(get_TaskListId, None)
class IUserDataTaskListSyncManagerSyncRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSyncManagerSyncRequestEventArgs'
    _iid_ = Guid('{8ead1c12-768e-43bd-8385-5cdc351ffdea}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSyncManagerSyncRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class UserDataTaskDataProviderConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection'
    @winrt_mixinmethod
    def add_CreateOrUpdateTaskRequested(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection, win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCreateOrUpdateTaskRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CreateOrUpdateTaskRequested(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SyncRequested(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection, win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSyncManagerSyncRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SyncRequested(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SkipOccurrenceRequested(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection, win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSkipOccurrenceRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SkipOccurrenceRequested(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CompleteTaskRequested(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection, win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCompleteTaskRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CompleteTaskRequested(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DeleteTaskRequested(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection, win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListDeleteTaskRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DeleteTaskRequested(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Start(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderConnection) -> Void: ...
    CreateOrUpdateTaskRequested = event()
    SyncRequested = event()
    SkipOccurrenceRequested = event()
    CompleteTaskRequested = event()
    DeleteTaskRequested = event()
class UserDataTaskDataProviderTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderTriggerDetails
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderTriggerDetails'
    @winrt_mixinmethod
    def get_Connection(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskDataProviderTriggerDetails) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskDataProviderConnection: ...
    Connection = property(get_Connection, None)
class UserDataTaskListCompleteTaskRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCompleteTaskRequest
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCompleteTaskRequest'
    @winrt_mixinmethod
    def get_TaskListId(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCompleteTaskRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_TaskId(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCompleteTaskRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCompleteTaskRequest, completedTaskId: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCompleteTaskRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    TaskId = property(get_TaskId, None)
    TaskListId = property(get_TaskListId, None)
class UserDataTaskListCompleteTaskRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCompleteTaskRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCompleteTaskRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCompleteTaskRequestEventArgs) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCompleteTaskRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCompleteTaskRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class UserDataTaskListCreateOrUpdateTaskRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCreateOrUpdateTaskRequest
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCreateOrUpdateTaskRequest'
    @winrt_mixinmethod
    def get_TaskListId(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCreateOrUpdateTaskRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Task(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCreateOrUpdateTaskRequest) -> win32more.Windows.ApplicationModel.UserDataTasks.UserDataTask: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCreateOrUpdateTaskRequest, createdOrUpdatedUserDataTask: win32more.Windows.ApplicationModel.UserDataTasks.UserDataTask) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCreateOrUpdateTaskRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    Task = property(get_Task, None)
    TaskListId = property(get_TaskListId, None)
class UserDataTaskListCreateOrUpdateTaskRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCreateOrUpdateTaskRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCreateOrUpdateTaskRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCreateOrUpdateTaskRequestEventArgs) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListCreateOrUpdateTaskRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListCreateOrUpdateTaskRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class UserDataTaskListDeleteTaskRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListDeleteTaskRequest
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListDeleteTaskRequest'
    @winrt_mixinmethod
    def get_TaskListId(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListDeleteTaskRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_TaskId(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListDeleteTaskRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListDeleteTaskRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListDeleteTaskRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    TaskId = property(get_TaskId, None)
    TaskListId = property(get_TaskListId, None)
class UserDataTaskListDeleteTaskRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListDeleteTaskRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListDeleteTaskRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListDeleteTaskRequestEventArgs) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListDeleteTaskRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListDeleteTaskRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class UserDataTaskListSkipOccurrenceRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSkipOccurrenceRequest
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSkipOccurrenceRequest'
    @winrt_mixinmethod
    def get_TaskListId(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSkipOccurrenceRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_TaskId(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSkipOccurrenceRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSkipOccurrenceRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSkipOccurrenceRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    TaskId = property(get_TaskId, None)
    TaskListId = property(get_TaskListId, None)
class UserDataTaskListSkipOccurrenceRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSkipOccurrenceRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSkipOccurrenceRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSkipOccurrenceRequestEventArgs) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSkipOccurrenceRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSkipOccurrenceRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class UserDataTaskListSyncManagerSyncRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSyncManagerSyncRequest
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSyncManagerSyncRequest'
    @winrt_mixinmethod
    def get_TaskListId(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSyncManagerSyncRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSyncManagerSyncRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSyncManagerSyncRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    TaskListId = property(get_TaskListId, None)
class UserDataTaskListSyncManagerSyncRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSyncManagerSyncRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSyncManagerSyncRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSyncManagerSyncRequestEventArgs) -> win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.UserDataTaskListSyncManagerSyncRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.UserDataTasks.DataProvider.IUserDataTaskListSyncManagerSyncRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security.EnterpriseData
import win32more.Windows.Win32.Storage.Packaging.Appx
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
@winfunctype('srpapi.dll')
def SrpCreateThreadNetworkContext(enterpriseId: win32more.Windows.Win32.Foundation.PWSTR, threadNetworkContext: POINTER(win32more.Windows.Win32.Security.EnterpriseData.HTHREAD_NETWORK_CONTEXT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('srpapi.dll')
def SrpCloseThreadNetworkContext(threadNetworkContext: POINTER(win32more.Windows.Win32.Security.EnterpriseData.HTHREAD_NETWORK_CONTEXT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('srpapi.dll')
def SrpSetTokenEnterpriseId(tokenHandle: win32more.Windows.Win32.Foundation.HANDLE, enterpriseId: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('srpapi.dll')
def SrpGetEnterpriseIds(tokenHandle: win32more.Windows.Win32.Foundation.HANDLE, numberOfBytes: POINTER(UInt32), enterpriseIds: POINTER(win32more.Windows.Win32.Foundation.PWSTR), enterpriseIdCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('srpapi.dll')
def SrpEnablePermissiveModeFileEncryption(enterpriseId: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('srpapi.dll')
def SrpDisablePermissiveModeFileEncryption() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('srpapi.dll')
def SrpGetEnterprisePolicy(tokenHandle: win32more.Windows.Win32.Foundation.HANDLE, policyFlags: POINTER(win32more.Windows.Win32.Security.EnterpriseData.ENTERPRISE_DATA_POLICIES)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('srpapi.dll')
def SrpIsTokenService(TokenHandle: win32more.Windows.Win32.Foundation.HANDLE, IsTokenService: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('srpapi.dll')
def SrpDoesPolicyAllowAppExecution(packageId: POINTER(win32more.Windows.Win32.Storage.Packaging.Appx.PACKAGE_ID), isAllowed: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('srpapi.dll')
def SrpHostingInitialize(Version: win32more.Windows.Win32.Security.EnterpriseData.SRPHOSTING_VERSION, Type: win32more.Windows.Win32.Security.EnterpriseData.SRPHOSTING_TYPE, pvData: VoidPtr, cbData: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('srpapi.dll')
def SrpHostingTerminate(Type: win32more.Windows.Win32.Security.EnterpriseData.SRPHOSTING_TYPE) -> Void: ...
@winfunctype('efswrt.dll')
def ProtectFileToEnterpriseIdentity(fileOrFolderPath: win32more.Windows.Win32.Foundation.PWSTR, identity: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('efswrt.dll')
def UnprotectFile(fileOrFolderPath: win32more.Windows.Win32.Foundation.PWSTR, options: POINTER(win32more.Windows.Win32.Security.EnterpriseData.FILE_UNPROTECT_OPTIONS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
ENTERPRISE_DATA_POLICIES = Int32
ENTERPRISE_POLICY_NONE: win32more.Windows.Win32.Security.EnterpriseData.ENTERPRISE_DATA_POLICIES = 0
ENTERPRISE_POLICY_ALLOWED: win32more.Windows.Win32.Security.EnterpriseData.ENTERPRISE_DATA_POLICIES = 1
ENTERPRISE_POLICY_ENLIGHTENED: win32more.Windows.Win32.Security.EnterpriseData.ENTERPRISE_DATA_POLICIES = 2
ENTERPRISE_POLICY_EXEMPT: win32more.Windows.Win32.Security.EnterpriseData.ENTERPRISE_DATA_POLICIES = 4
class FILE_UNPROTECT_OPTIONS(Structure):
    audit: Byte
class HTHREAD_NETWORK_CONTEXT(Structure):
    ThreadId: UInt32
    ThreadContext: win32more.Windows.Win32.Foundation.HANDLE
class IProtectionPolicyManagerInterop(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _iid_ = Guid('{4652651d-c1fe-4ba1-9f0a-c0f56596f721}')
    @commethod(6)
    def RequestAccessForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, targetIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetForWindow(self, appWindow: win32more.Windows.Win32.Foundation.HWND, riid: POINTER(Guid), result: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IProtectionPolicyManagerInterop2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _iid_ = Guid('{157cfbe4-a78d-4156-b384-61fdac41e686}')
    @commethod(6)
    def RequestAccessForAppWithWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, appPackageFamilyName: win32more.Windows.Win32.System.WinRT.HSTRING, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RequestAccessWithAuditingInfoForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, targetIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, auditInfoUnk: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RequestAccessWithMessageForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, targetIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, auditInfoUnk: win32more.Windows.Win32.System.Com.IUnknown, messageFromApp: win32more.Windows.Win32.System.WinRT.HSTRING, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RequestAccessForAppWithAuditingInfoForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, appPackageFamilyName: win32more.Windows.Win32.System.WinRT.HSTRING, auditInfoUnk: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def RequestAccessForAppWithMessageForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, appPackageFamilyName: win32more.Windows.Win32.System.WinRT.HSTRING, auditInfoUnk: win32more.Windows.Win32.System.Com.IUnknown, messageFromApp: win32more.Windows.Win32.System.WinRT.HSTRING, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IProtectionPolicyManagerInterop3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _iid_ = Guid('{c1c03933-b398-4d93-b0fd-2972adf802c2}')
    @commethod(6)
    def RequestAccessWithBehaviorForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, targetIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, auditInfoUnk: win32more.Windows.Win32.System.Com.IUnknown, messageFromApp: win32more.Windows.Win32.System.WinRT.HSTRING, behavior: UInt32, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RequestAccessForAppWithBehaviorForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceIdentity: win32more.Windows.Win32.System.WinRT.HSTRING, appPackageFamilyName: win32more.Windows.Win32.System.WinRT.HSTRING, auditInfoUnk: win32more.Windows.Win32.System.Com.IUnknown, messageFromApp: win32more.Windows.Win32.System.WinRT.HSTRING, behavior: UInt32, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RequestAccessToFilesForAppForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceItemListUnk: win32more.Windows.Win32.System.Com.IUnknown, appPackageFamilyName: win32more.Windows.Win32.System.WinRT.HSTRING, auditInfoUnk: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RequestAccessToFilesForAppWithMessageAndBehaviorForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceItemListUnk: win32more.Windows.Win32.System.Com.IUnknown, appPackageFamilyName: win32more.Windows.Win32.System.WinRT.HSTRING, auditInfoUnk: win32more.Windows.Win32.System.Com.IUnknown, messageFromApp: win32more.Windows.Win32.System.WinRT.HSTRING, behavior: UInt32, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def RequestAccessToFilesForProcessForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceItemListUnk: win32more.Windows.Win32.System.Com.IUnknown, processId: UInt32, auditInfoUnk: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def RequestAccessToFilesForProcessWithMessageAndBehaviorForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, sourceItemListUnk: win32more.Windows.Win32.System.Com.IUnknown, processId: UInt32, auditInfoUnk: win32more.Windows.Win32.System.Com.IUnknown, messageFromApp: win32more.Windows.Win32.System.WinRT.HSTRING, behavior: UInt32, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
SRPHOSTING_TYPE = Int32
SRPHOSTING_TYPE_NONE: win32more.Windows.Win32.Security.EnterpriseData.SRPHOSTING_TYPE = 0
SRPHOSTING_TYPE_WINHTTP: win32more.Windows.Win32.Security.EnterpriseData.SRPHOSTING_TYPE = 1
SRPHOSTING_TYPE_WININET: win32more.Windows.Win32.Security.EnterpriseData.SRPHOSTING_TYPE = 2
SRPHOSTING_VERSION = Int32
SRPHOSTING_VERSION1: win32more.Windows.Win32.Security.EnterpriseData.SRPHOSTING_VERSION = 1


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.Graphics.Display
import win32more.Microsoft.UI
import win32more.Microsoft.UI.Dispatching
import win32more.Windows.Foundation
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class DisplayAdvancedColorInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo
    _classid_ = 'Microsoft.Graphics.Display.DisplayAdvancedColorInfo'
    @winrt_mixinmethod
    def get_CurrentAdvancedColorKind(self: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo) -> win32more.Microsoft.Graphics.Display.DisplayAdvancedColorKind: ...
    @winrt_mixinmethod
    def get_RedPrimary(self: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_GreenPrimary(self: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_BluePrimary(self: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_WhitePoint(self: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_MaxLuminanceInNits(self: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo) -> Double: ...
    @winrt_mixinmethod
    def get_MinLuminanceInNits(self: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo) -> Double: ...
    @winrt_mixinmethod
    def get_MaxAverageFullFrameLuminanceInNits(self: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo) -> Double: ...
    @winrt_mixinmethod
    def get_SdrWhiteLevelInNits(self: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo) -> Double: ...
    @winrt_mixinmethod
    def IsHdrMetadataFormatCurrentlySupported(self: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo, format: win32more.Microsoft.Graphics.Display.DisplayHdrMetadataFormat) -> Boolean: ...
    @winrt_mixinmethod
    def IsAdvancedColorKindAvailable(self: win32more.Microsoft.Graphics.Display.IDisplayAdvancedColorInfo, kind: win32more.Microsoft.Graphics.Display.DisplayAdvancedColorKind) -> Boolean: ...
    BluePrimary = property(get_BluePrimary, None)
    CurrentAdvancedColorKind = property(get_CurrentAdvancedColorKind, None)
    GreenPrimary = property(get_GreenPrimary, None)
    MaxAverageFullFrameLuminanceInNits = property(get_MaxAverageFullFrameLuminanceInNits, None)
    MaxLuminanceInNits = property(get_MaxLuminanceInNits, None)
    MinLuminanceInNits = property(get_MinLuminanceInNits, None)
    RedPrimary = property(get_RedPrimary, None)
    SdrWhiteLevelInNits = property(get_SdrWhiteLevelInNits, None)
    WhitePoint = property(get_WhitePoint, None)
class DisplayAdvancedColorKind(Enum, Int32):
    StandardDynamicRange = 0
    WideColorGamut = 1
    HighDynamicRange = 2
class DisplayHdrMetadataFormat(Enum, Int32):
    Hdr10 = 0
    Hdr10Plus = 1
class DisplayInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.Graphics.Display.IDisplayInformation
    _classid_ = 'Microsoft.Graphics.Display.DisplayInformation'
    @winrt_mixinmethod
    def get_IsStereoEnabled(self: win32more.Microsoft.Graphics.Display.IDisplayInformation) -> Boolean: ...
    @winrt_mixinmethod
    def GetColorProfileAsync(self: win32more.Microsoft.Graphics.Display.IDisplayInformation) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_mixinmethod
    def add_IsStereoEnabledChanged(self: win32more.Microsoft.Graphics.Display.IDisplayInformation, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsStereoEnabledChanged(self: win32more.Microsoft.Graphics.Display.IDisplayInformation, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Microsoft.Graphics.Display.IDisplayInformation) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_mixinmethod
    def GetColorProfile(self: win32more.Microsoft.Graphics.Display.IDisplayInformation) -> win32more.Windows.Storage.Streams.IRandomAccessStream: ...
    @winrt_mixinmethod
    def add_ColorProfileChanged(self: win32more.Microsoft.Graphics.Display.IDisplayInformation, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ColorProfileChanged(self: win32more.Microsoft.Graphics.Display.IDisplayInformation, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetAdvancedColorInfo(self: win32more.Microsoft.Graphics.Display.IDisplayInformation) -> win32more.Microsoft.Graphics.Display.DisplayAdvancedColorInfo: ...
    @winrt_mixinmethod
    def add_AdvancedColorInfoChanged(self: win32more.Microsoft.Graphics.Display.IDisplayInformation, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AdvancedColorInfoChanged(self: win32more.Microsoft.Graphics.Display.IDisplayInformation, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Destroyed(self: win32more.Microsoft.Graphics.Display.IDisplayInformation, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Destroyed(self: win32more.Microsoft.Graphics.Display.IDisplayInformation, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def CreateForWindowId(cls: win32more.Microsoft.Graphics.Display.IDisplayInformationStatics, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.Graphics.Display.DisplayInformation: ...
    @winrt_classmethod
    def CreateForDisplayId(cls: win32more.Microsoft.Graphics.Display.IDisplayInformationStatics, displayId: win32more.Microsoft.UI.DisplayId) -> win32more.Microsoft.Graphics.Display.DisplayInformation: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
    IsStereoEnabled = property(get_IsStereoEnabled, None)
    IsStereoEnabledChanged = event()
    ColorProfileChanged = event()
    AdvancedColorInfoChanged = event()
    Destroyed = event()
class IDisplayAdvancedColorInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Graphics.Display.IDisplayAdvancedColorInfo'
    _iid_ = Guid('{b44f0f47-7065-5175-ba3e-714489c85a3e}')
    @winrt_commethod(6)
    def get_CurrentAdvancedColorKind(self) -> win32more.Microsoft.Graphics.Display.DisplayAdvancedColorKind: ...
    @winrt_commethod(7)
    def get_RedPrimary(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(8)
    def get_GreenPrimary(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(9)
    def get_BluePrimary(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(10)
    def get_WhitePoint(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(11)
    def get_MaxLuminanceInNits(self) -> Double: ...
    @winrt_commethod(12)
    def get_MinLuminanceInNits(self) -> Double: ...
    @winrt_commethod(13)
    def get_MaxAverageFullFrameLuminanceInNits(self) -> Double: ...
    @winrt_commethod(14)
    def get_SdrWhiteLevelInNits(self) -> Double: ...
    @winrt_commethod(15)
    def IsHdrMetadataFormatCurrentlySupported(self, format: win32more.Microsoft.Graphics.Display.DisplayHdrMetadataFormat) -> Boolean: ...
    @winrt_commethod(16)
    def IsAdvancedColorKindAvailable(self, kind: win32more.Microsoft.Graphics.Display.DisplayAdvancedColorKind) -> Boolean: ...
    BluePrimary = property(get_BluePrimary, None)
    CurrentAdvancedColorKind = property(get_CurrentAdvancedColorKind, None)
    GreenPrimary = property(get_GreenPrimary, None)
    MaxAverageFullFrameLuminanceInNits = property(get_MaxAverageFullFrameLuminanceInNits, None)
    MaxLuminanceInNits = property(get_MaxLuminanceInNits, None)
    MinLuminanceInNits = property(get_MinLuminanceInNits, None)
    RedPrimary = property(get_RedPrimary, None)
    SdrWhiteLevelInNits = property(get_SdrWhiteLevelInNits, None)
    WhitePoint = property(get_WhitePoint, None)
class IDisplayInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Graphics.Display.IDisplayInformation'
    _iid_ = Guid('{f0d58d4f-84ce-5b27-b222-4f8f7dc0aaeb}')
    @winrt_commethod(6)
    def get_DispatcherQueue(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_commethod(7)
    def get_IsStereoEnabled(self) -> Boolean: ...
    @winrt_commethod(8)
    def add_IsStereoEnabledChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_IsStereoEnabledChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def GetColorProfileAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_commethod(11)
    def GetColorProfile(self) -> win32more.Windows.Storage.Streams.IRandomAccessStream: ...
    @winrt_commethod(12)
    def add_ColorProfileChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_ColorProfileChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def GetAdvancedColorInfo(self) -> win32more.Microsoft.Graphics.Display.DisplayAdvancedColorInfo: ...
    @winrt_commethod(15)
    def add_AdvancedColorInfoChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_AdvancedColorInfoChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def add_Destroyed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_Destroyed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
    IsStereoEnabled = property(get_IsStereoEnabled, None)
    IsStereoEnabledChanged = event()
    ColorProfileChanged = event()
    AdvancedColorInfoChanged = event()
    Destroyed = event()
class IDisplayInformationStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Graphics.Display.IDisplayInformationStatics'
    _iid_ = Guid('{2de85048-37fa-56c0-ac30-47e2044d7ea8}')
    @winrt_commethod(6)
    def CreateForWindowId(self, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.Graphics.Display.DisplayInformation: ...
    @winrt_commethod(7)
    def CreateForDisplayId(self, displayId: win32more.Microsoft.UI.DisplayId) -> win32more.Microsoft.Graphics.Display.DisplayInformation: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.SettingsManagementInfrastructure
import win32more.Windows.Win32.System.Variant
WCM_SETTINGS_ID_NAME: String = 'name'
WCM_SETTINGS_ID_VERSION: String = 'version'
WCM_SETTINGS_ID_LANGUAGE: String = 'language'
WCM_SETTINGS_ID_ARCHITECTURE: String = 'architecture'
WCM_SETTINGS_ID_TOKEN: String = 'token'
WCM_SETTINGS_ID_URI: String = 'uri'
WCM_SETTINGS_ID_VERSION_SCOPE: String = 'versionScope'
WCM_SETTINGS_ID_FLAG_REFERENCE: UInt32 = 0
WCM_SETTINGS_ID_FLAG_DEFINITION: UInt32 = 1
LINK_STORE_TO_ENGINE_INSTANCE: UInt32 = 1
LIMITED_VALIDATION_MODE: UInt32 = 1
WCM_E_INTERNALERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145255424
WCM_E_STATENODENOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145255423
WCM_E_STATENODENOTALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2145255422
WCM_E_ATTRIBUTENOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145255421
WCM_E_ATTRIBUTENOTALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2145255420
WCM_E_INVALIDVALUE: win32more.Windows.Win32.Foundation.HRESULT = -2145255419
WCM_E_INVALIDVALUEFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2145255418
WCM_E_TYPENOTSPECIFIED: win32more.Windows.Win32.Foundation.HRESULT = -2145255417
WCM_E_INVALIDDATATYPE: win32more.Windows.Win32.Foundation.HRESULT = -2145255416
WCM_E_NOTPOSITIONED: win32more.Windows.Win32.Foundation.HRESULT = -2145255415
WCM_E_READONLYITEM: win32more.Windows.Win32.Foundation.HRESULT = -2145255414
WCM_E_INVALIDPATH: win32more.Windows.Win32.Foundation.HRESULT = -2145255413
WCM_E_WRONGESCAPESTRING: win32more.Windows.Win32.Foundation.HRESULT = -2145255412
WCM_E_INVALIDVERSIONFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2145255411
WCM_E_INVALIDLANGUAGEFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2145255410
WCM_E_KEYNOTCHANGEABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145255409
WCM_E_EXPRESSIONNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145255408
WCM_E_SUBSTITUTIONNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145255407
WCM_E_USERALREADYREGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2145255406
WCM_E_USERNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145255405
WCM_E_NAMESPACENOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145255404
WCM_E_NAMESPACEALREADYREGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2145255403
WCM_E_STORECORRUPTED: win32more.Windows.Win32.Foundation.HRESULT = -2145255402
WCM_E_INVALIDEXPRESSIONSYNTAX: win32more.Windows.Win32.Foundation.HRESULT = -2145255401
WCM_E_NOTIFICATIONNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145255400
WCM_E_CONFLICTINGASSERTION: win32more.Windows.Win32.Foundation.HRESULT = -2145255399
WCM_E_ASSERTIONFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145255398
WCM_E_DUPLICATENAME: win32more.Windows.Win32.Foundation.HRESULT = -2145255397
WCM_E_INVALIDKEY: win32more.Windows.Win32.Foundation.HRESULT = -2145255396
WCM_E_INVALIDSTREAM: win32more.Windows.Win32.Foundation.HRESULT = -2145255395
WCM_E_HANDLERNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145255394
WCM_E_INVALIDHANDLERSYNTAX: win32more.Windows.Win32.Foundation.HRESULT = -2145255393
WCM_E_VALIDATIONFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145255392
WCM_E_RESTRICTIONFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145255391
WCM_E_MANIFESTCOMPILATIONFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145255390
WCM_E_CYCLICREFERENCE: win32more.Windows.Win32.Foundation.HRESULT = -2145255389
WCM_E_MIXTYPEASSERTION: win32more.Windows.Win32.Foundation.HRESULT = -2145255388
WCM_E_NOTSUPPORTEDFUNCTION: win32more.Windows.Win32.Foundation.HRESULT = -2145255387
WCM_E_VALUETOOBIG: win32more.Windows.Win32.Foundation.HRESULT = -2145255386
WCM_E_INVALIDATTRIBUTECOMBINATION: win32more.Windows.Win32.Foundation.HRESULT = -2145255385
WCM_E_ABORTOPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2145255384
WCM_E_MISSINGCONFIGURATION: win32more.Windows.Win32.Foundation.HRESULT = -2145255383
WCM_E_INVALIDPROCESSORFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2145255382
WCM_E_SOURCEMANEMPTYVALUE: win32more.Windows.Win32.Foundation.HRESULT = -2145255381
WCM_S_INTERNALERROR: win32more.Windows.Win32.Foundation.HRESULT = 2232320
WCM_S_ATTRIBUTENOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = 2232321
WCM_S_LEGACYSETTINGWARNING: win32more.Windows.Win32.Foundation.HRESULT = 2232322
WCM_S_INVALIDATTRIBUTECOMBINATION: win32more.Windows.Win32.Foundation.HRESULT = 2232324
WCM_S_ATTRIBUTENOTALLOWED: win32more.Windows.Win32.Foundation.HRESULT = 2232325
WCM_S_NAMESPACENOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = 2232326
WCM_E_UNKNOWNRESULT: win32more.Windows.Win32.Foundation.HRESULT = -2145251325
class IItemEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9f7d7bb7-20b3-11da-81a5-0030f1642e3c}')
    @commethod(3)
    def Current(self, Item: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MoveNext(self, ItemValid: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISettingsContext(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9f7d7bbd-20b3-11da-81a5-0030f1642e3c}')
    @commethod(3)
    def Serialize(self, pStream: win32more.Windows.Win32.System.Com.IStream, pTarget: win32more.Windows.Win32.System.SettingsManagementInfrastructure.ITargetInfo) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Deserialize(self, pStream: win32more.Windows.Win32.System.Com.IStream, pTarget: win32more.Windows.Win32.System.SettingsManagementInfrastructure.ITargetInfo, pppResults: POINTER(POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsResult)), pcResultCount: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetUserData(self, pUserData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetUserData(self, pUserData: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetNamespaces(self, ppNamespaceIds: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.IItemEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetStoredSettings(self, pIdentity: win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsIdentity, ppAddedSettings: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.IItemEnumerator), ppModifiedSettings: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.IItemEnumerator), ppDeletedSettings: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.IItemEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RevertSetting(self, pIdentity: win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsIdentity, pwzSetting: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISettingsEngine(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9f7d7bb9-20b3-11da-81a5-0030f1642e3c}')
    @commethod(3)
    def GetNamespaces(self, Flags: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmNamespaceEnumerationFlags, Reserved: VoidPtr, Namespaces: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.IItemEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNamespace(self, SettingsID: win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsIdentity, Access: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmNamespaceAccess, Reserved: VoidPtr, NamespaceItem: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsNamespace)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetErrorDescription(self, HResult: Int32, Message: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateSettingsIdentity(self, SettingsID: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsIdentity)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetStoreStatus(self, Reserved: VoidPtr, Status: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmUserStatus)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def LoadStore(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def UnloadStore(self, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def RegisterNamespace(self, SettingsID: win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsIdentity, Stream: win32more.Windows.Win32.System.Com.IStream, PushSettings: win32more.Windows.Win32.Foundation.BOOL, Results: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def UnregisterNamespace(self, SettingsID: win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsIdentity, RemoveSettings: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CreateTargetInfo(self, Target: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ITargetInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetTargetInfo(self, Target: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ITargetInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetTargetInfo(self, Target: win32more.Windows.Win32.System.SettingsManagementInfrastructure.ITargetInfo) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def CreateSettingsContext(self, Flags: UInt32, Reserved: VoidPtr, SettingsContext: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetSettingsContext(self, SettingsContext: win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsContext) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ApplySettingsContext(self, SettingsContext: win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsContext, pppwzIdentities: POINTER(POINTER(win32more.Windows.Win32.Foundation.PWSTR)), pcIdentities: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetSettingsContext(self, SettingsContext: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISettingsIdentity(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9f7d7bb6-20b3-11da-81a5-0030f1642e3c}')
    @commethod(3)
    def GetAttribute(self, Reserved: VoidPtr, Name: win32more.Windows.Win32.Foundation.PWSTR, Value: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetAttribute(self, Reserved: VoidPtr, Name: win32more.Windows.Win32.Foundation.PWSTR, Value: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetFlags(self, Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetFlags(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISettingsItem(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9f7d7bbb-20b3-11da-81a5-0030f1642e3c}')
    @commethod(3)
    def GetName(self, Name: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetValue(self, Value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetValue(self, Value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetSettingType(self, Type: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmSettingType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetDataType(self, Type: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetValueRaw(self, Data: POINTER(POINTER(Byte)), DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetValueRaw(self, DataType: Int32, Data: POINTER(Byte), DataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def HasChild(self, ItemHasChild: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Children(self, Children: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.IItemEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetChild(self, Name: win32more.Windows.Win32.Foundation.PWSTR, Child: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetSettingByPath(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Setting: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateSettingByPath(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Setting: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def RemoveSettingByPath(self, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetListKeyInformation(self, KeyName: POINTER(win32more.Windows.Win32.Foundation.BSTR), DataType: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def CreateListElement(self, KeyData: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), Child: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def RemoveListElement(self, ElementName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def Attributes(self, Attributes: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.IItemEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetAttribute(self, Name: win32more.Windows.Win32.Foundation.PWSTR, Value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetPath(self, Path: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetRestrictionFacets(self, RestrictionFacets: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmRestrictionFacets)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetRestriction(self, RestrictionFacet: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmRestrictionFacets, FacetData: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetKeyValue(self, Value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISettingsNamespace(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9f7d7bba-20b3-11da-81a5-0030f1642e3c}')
    @commethod(3)
    def GetIdentity(self, SettingsID: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsIdentity)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Settings(self, Settings: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.IItemEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Save(self, PushSettings: win32more.Windows.Win32.Foundation.BOOL, Result: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetSettingByPath(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Setting: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateSettingByPath(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Setting: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.ISettingsItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RemoveSettingByPath(self, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetAttribute(self, Name: win32more.Windows.Win32.Foundation.PWSTR, Value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISettingsResult(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9f7d7bbc-20b3-11da-81a5-0030f1642e3c}')
    @commethod(3)
    def GetDescription(self, description: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetErrorCode(self, hrOut: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetContextDescription(self, description: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetLine(self, dwLine: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetColumn(self, dwColumn: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetSource(self, file: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITargetInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9f7d7bb8-20b3-11da-81a5-0030f1642e3c}')
    @commethod(3)
    def GetTargetMode(self, TargetMode: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmTargetMode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetTargetMode(self, TargetMode: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmTargetMode) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetTemporaryStoreLocation(self, TemporaryStoreLocation: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetTemporaryStoreLocation(self, TemporaryStoreLocation: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetTargetID(self, TargetID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetTargetID(self, TargetID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetTargetProcessorArchitecture(self, ProcessorArchitecture: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetTargetProcessorArchitecture(self, ProcessorArchitecture: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetProperty(self, Offline: win32more.Windows.Win32.Foundation.BOOL, Property: win32more.Windows.Win32.Foundation.PWSTR, Value: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetProperty(self, Offline: win32more.Windows.Win32.Foundation.BOOL, Property: win32more.Windows.Win32.Foundation.PWSTR, Value: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetEnumerator(self, Enumerator: POINTER(win32more.Windows.Win32.System.SettingsManagementInfrastructure.IItemEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ExpandTarget(self, Offline: win32more.Windows.Win32.Foundation.BOOL, Location: win32more.Windows.Win32.Foundation.PWSTR, ExpandedLocation: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def ExpandTargetPath(self, Offline: win32more.Windows.Win32.Foundation.BOOL, Location: win32more.Windows.Win32.Foundation.PWSTR, ExpandedLocation: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetModulePath(self, Module: win32more.Windows.Win32.Foundation.PWSTR, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def LoadModule(self, Module: win32more.Windows.Win32.Foundation.PWSTR, ModuleHandle: POINTER(win32more.Windows.Win32.Foundation.HMODULE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetWow64Context(self, InstallerModule: win32more.Windows.Win32.Foundation.PWSTR, Wow64Context: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def TranslateWow64(self, ClientArchitecture: win32more.Windows.Win32.Foundation.PWSTR, Value: win32more.Windows.Win32.Foundation.PWSTR, TranslatedValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetSchemaHiveLocation(self, pwzHiveDir: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetSchemaHiveLocation(self, pHiveLocation: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SetSchemaHiveMountName(self, pwzMountName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetSchemaHiveMountName(self, pMountName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
SettingsEngine = Guid('{9f7d7bb5-20b3-11da-81a5-0030f1642e3c}')
WcmDataType = Int32
dataTypeByte: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType = 1
dataTypeSByte: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType = 2
dataTypeUInt16: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType = 3
dataTypeInt16: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType = 4
dataTypeUInt32: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType = 5
dataTypeInt32: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType = 6
dataTypeUInt64: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType = 7
dataTypeInt64: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType = 8
dataTypeBoolean: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType = 11
dataTypeString: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType = 12
dataTypeFlagArray: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmDataType = 32768
WcmNamespaceAccess = Int32
ReadOnlyAccess: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmNamespaceAccess = 1
ReadWriteAccess: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmNamespaceAccess = 2
WcmNamespaceEnumerationFlags = Int32
SharedEnumeration: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmNamespaceEnumerationFlags = 1
UserEnumeration: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmNamespaceEnumerationFlags = 2
AllEnumeration: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmNamespaceEnumerationFlags = 3
WcmRestrictionFacets = Int32
restrictionFacetMaxLength: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmRestrictionFacets = 1
restrictionFacetEnumeration: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmRestrictionFacets = 2
restrictionFacetMaxInclusive: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmRestrictionFacets = 4
restrictionFacetMinInclusive: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmRestrictionFacets = 8
WcmSettingType = Int32
settingTypeScalar: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmSettingType = 1
settingTypeComplex: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmSettingType = 2
settingTypeList: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmSettingType = 3
WcmTargetMode = Int32
OfflineMode: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmTargetMode = 1
OnlineMode: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmTargetMode = 2
WcmUserStatus = Int32
UnknownStatus: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmUserStatus = 0
UserRegistered: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmUserStatus = 1
UserUnregistered: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmUserStatus = 2
UserLoaded: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmUserStatus = 3
UserUnloaded: win32more.Windows.Win32.System.SettingsManagementInfrastructure.WcmUserStatus = 4


make_ready(__name__)
